# ![](img/nav42/admin.png) System administration

## The software sources

![](img/apps/software.png#left)  
Debian GNU/Linux uses the repository methodology to distribute applications. 
This methodology allows the software centralization and the usage of simple 
interfaces to administrate and upgrade your system: you have no need to visit 
the software sites themselves.

### The sources.list file

The Internet addresses of the Debian repositories are stored in the 
**/etc/apt/sources.list** file, as well as the files of the type 
**/etc/apt/sources.list.d/xxx.list**.

To edit and modify your *sources.list* file, you can use the **apt edit-sources** 
command.

![An example of 'sources.list' file on Debian 10](img/08-admin/01-sources-list.jpg)

Details concerning the various information found in the 'sources.list' 
file (the lines beginning with a "#" are just comments):

- "deb": means a *binary* repository (the compiled software itself)
- "deb-src": means a *source* repository (the program code files used 
to compile the software)
- "http:..." or "https:...": the Internet address of the repository server
- "buster" or "buster-updates": the branch in the repository tree
- "main": the repository section.

![](img/misc/noob-info.png#left)  
**... why "buster" and not "stable" since the system is based on Debian Stable ??**  
"**buster**"  is the precise version name of the installed system. It sets a 
given version of each packages included in the "buster" repository (the 
version of the generic kernel, for example).  
"**stable**" is the generic name of the *currently* stable version.  
For the time being, Debian 10 "buster" is the "stable" version, thus you could used 
either designation. But when the Debian "stable" version becomes Debian 11 "bullseye", 
then Debian 10 "buster" attribute will change to "oldstable".

Using the precise name of your version allows you to control **if and when** 
you want to upgrade your system to the next version, as opposed to some 
systems which want to impose their upgrades...  
For more detailed information, I invite you to visit the dedicated Debian wiki 
[https://www.debian.org/releases/index.html](https://www.debian.org/releases/index.html)

### About repositories, branches and sections/components

Debian organizes its software packages inside repositories. These repositories are divided 
into branches and sections/components. To learn more about the "testing" and 
"unstable" branches read the [chapter 8.9](#who-is-this-sid-guy). One word, however, 
about the sections/components inside the repositories.

There are 3 sections in the official Debian repositories:

- **main**: complies to the DFSG without any "non-free" dependency
- **contrib**: complies to the DFSG with some "non-free" dependencies
- **non-free**: does not comply to the DFSG

**DFSG** (**D**ebian **F**ree **S**oftware **G**uidelines) : philosophical 
principles of the "libre software" according to Debian (
[https://www.debian.org/social_contract.html#guidelines](https://www.debian.org/social_contract.html#guidelines))

Only the packages within the **main** section/component are officially supported 
by the Debian project and are 100% free software. Rather, those proposed in 
*contrib* and *non-free* are partially or totally non-free.

Having said that, and depending on your type of hardware, it is very 
possible that some services won't function correctly without using some 
specific (proprietary) drivers. In that case, you need to modify the 
/etc/apt/sources.list file (details in the following chapter)

- More details about the Debian versions in the Debian Wiki: 
[https://wiki.debian.org/DebianReleases](https://wiki.debian.org/DebianReleases).
- For more details on sources.list, it's here: 
[https://wiki.debian.org/SourcesList](https://wiki.debian.org/SourcesList).
- For a complete documentation on the Debian package management, it's there: 
[https://www.debian.org/doc/manuals/debian-reference/ch02.html](https://www.debian.org/doc/manuals/debian-reference/ch02.html).

### Backport packages

Debian offers also some special repositories called **backports**, which contain 
**more recent versions** of some applications. These repositories are not 
activated by default, but do not present any particular risks for your system: 
**the "regular" repositories have the highest priority during the update process**, 
only the applications installed from the backports will look into these specific 
repositories.

![](img/misc/noob-info.png#left)  
**... what do you mean exactly by "backports" ?**  
Nothing to do, in fact, with the "backdoors" used to spy on computers running 
proprietary systems...  
The **backport** is a mechanism allowing an application currently hold in the 
Debian development repositories, to be *ported back* to the "stable" version.  
For example, the Debian developers take from the development repositories the most 
recent version of LibreOffice, and re-compile (re-build) the package holding 
the application, while taking care of all the dependencies existing in the 
"stable" version.

More details about *Backports* in the dedicated page of the Debian wiki 
([https://wiki.debian.org/Backports](https://wiki.debian.org/Backports)).

If you are looking for specific application, you have two solutions:

- use the search package tool 
([https://backports.debian.org/Packages/](https://backports.debian.org/Packages/))
- use the search by category 
([https://packages.debian.org/buster-backports/](https://packages.debian.org/jessie-backports/)).

### Modifying the Repositories

Before you start modifying the software sources of your system, you must be 
conscious of the risks your are taking by using the "contrib" or "non-free" 
components of the archived branch :

- the lack of freedom for this kind of packages
- the lack of support by the Debian project (you cannot maintain a piece of 
software without having the source code at your disposal)
- the contamination of your completely free Debian system.

Now, that you are aware that the non-free people kill the pink rabbits, 
let's move on:

To modify your software sources, it is enough to edit the 'sources.list' 
file. Open a terminal in administrator mode ([chap.3.8.3](#administrator-mode-example)), and enter:

    apt edit-sources

This command opens the appropriate file with the default text editor 
(nano or vim). Once you are done with your modifications, save the file 
("[Ctrl]+x" with nano, or ":wq" with vim [http://www.vim.org/](http://www.vim.org/)).

**Example of line entry for the free packages:**

    deb http://deb.debian.org/debian/ stable main

**Example of line entry for the free packages and the proprietary packages:**

    deb http://deb.debian.org/debian/ stable main contrib non-free

Now you can pick in the 3 package sections and install the 
non-free codecs and drivers.

Note that you can also modify your software sources by using the graphical 
Synaptic package manager ([chap.8.3](#synaptic-the-comprehensive-package-manager)).

## APT in a terminal

![](img/apps/terminal.png#left)  
The following sections present the basic commands to manage de Debian packages with 
**APT** (**A**dvanced **P**ackage **T**ool) within your terminal emulator.

Debian supports also "aptitude", another package manager, with a different 
syntax and behavior. This manual being intended for beginners, no need to 
explicit these commands here: to learn more about them, visit the dedicated 
Debian Aptitude Wiki: 
[https://wiki.debian.org/Aptitude](https://wiki.debian.org/Aptitude).

### 'User' command to search and display information

These commands can be executed as simple user, because they do not impact 
your system.

Command                 Description
----------------------- -------------------------------------------
apt show *foo*          Display information about the package *foo*
apt search *foo*        Look for packages corresponding to the *foo*
apt-cache policy *foo*  Display the available version of *foo*

### 'Administrator' mode commands for system maintenance

These commands must be executed with the "root" administrator rights, 
because they impact the system. To move into the administrator mode from 
a terminal, type "**su -**": the administrator password is requested.

Command              Description
-------------------- ----------------------------------------------------------
apt update           Update the repositories metadata
apt install *foo*    Install the *foo* package and its dependencies
apt upgrade          Secured update of the installed packages
apt full-upgrade     Update of the installed packet, by adding/removing other packages if necessary
apt remove *foo*     Remove the *foo* package, but not the configuratrion files
apt autoremove       Auto remove the unecessary packages
apt purge *foo*      Purge the *foo* package and its configuration files
apt clean            Clean the local cache of the installed package
apt autoclean        Clean the local cache of the obsolete packages
apt-mark showmanual  Mark a package as being "manually-installed"

For more detailed information and the apt/aptitude equivalence, visit the 
dedicated page of the Debian manual: 
[https://www.debian.org/doc/manuals/debian-reference/ch02.html](https://www.debian.org/doc/manuals/debian-reference/ch02.html)

**All-in-One** command line (in administrator mode) to update the repositories 
information + update your system + clean the packages in cache:

    apt update && apt full-upgrade && apt autoclean

To delete useless packages, unecessary dependencies, and old configuration files 
in administrator mode:

    apt autoremove --purge

Which goes to demonstrate that managing your system with a terminal is not 
that complex. ![](img/smile/wink.png)

## Software : the simplified package manager

![](img/apps/logiciels.png#left)  
**Software** is a simplified manager for Debian applications. It allows you 
to search, install, delete or update packages containing your applications. 
You can find it in the "System" category of your menus or directly from the 
Gnome search box by typing "Software".

![Software: default Debian interface.](img/08-admin/02-logiciels.jpg)

### Software: searching an application

Directly by clicking on the search button (the magnifying glass symbol), 
or by selecting one of the displayed categories:

![Software: searching an application by its name.](img/08-admin/03-logiciels-search.jpg)

### Software: installing an application

You can **Install an application** simply by clicking on its description area 
and then on the "Install" button. 
The administrator password will be requested. You can follow the installation progress in 
the main window and then launch directly the newly downloaded application.

![Software: selecting an application for installation.](img/08-admin/04-logiciels-install-1.jpg)

![Software: authentication.](img/08-admin/05-logiciels-install-2.jpg)

![Software: you can follow the installation process.](img/08-admin/06-logiciels-install-3.jpg)

![Software: the installation was successful, you can launch your application.](img/08-admin/07-logiciels-install-4.jpg)

### Software: removing an application

You can **Uninstall an application** simply by visiting the "Installed" category 
(at the top of the interface) and then by clicking on the "Remove" button. You will 
be asked for confirmation:

![Software: selecting an application for removal.](img/08-admin/08-logiciels-remove-1.jpg)

![Software: confirmation](img/08-admin/09-logiciels-remove-2.jpg)

### Software: upgrading your applications

You can **Update your system** from the dedicated section "Updates" which will indicate 
the available and/or already downloaded updates. If no update is available, you 
can check the repositories by using the dedicated button at the top left.  
![](img/08-admin/10-logiciels-upgrade-refresh.jpg)  
In our example, a set of updates including an "operating system update" 
requires a reboot. We start by downloading the packet to update:

![Software: updates tab](img/08-admin/10-logiciels-upgrade-1.jpg)

You then have to restart the system by clicking on the dedicated button.

![Software: downloading updates](img/08-admin/11-logiciels-upgrade-2.jpg)

![Software: reboot to apply updates](img/08-admin/12-logiciels-upgrade-3.jpg)

Note that for lighter updates, restart is not necessary.

After reboot, a message window on the desktop informs you that the install was 
successful.

![Software: successful update notification](img/08-admin/13-logiciels-upgrade-4.jpg)

### Software: modify packages repositories

The "Software" application is rather simple, but still allows you to
configure your repositories graphically. From the menu, choose "Repositories". 
You can add "non-free" sources and/or define the 
frequency of the repositories updates. The repository adresse information on display 
are coming from your sources.list file ([chap.8.1.1](#the-sources.list-file)).

![Software: repositories menu](img/08-admin/14-logiciels-menu-depots.jpg)

![Software: repositories modification](img/08-admin/15-logiciels-depots-1.jpg)

![Software: update frequency](img/08-admin/16-logiciels-depots-2.jpg)

Once your repositories have been modified, you must reload the information 
packages. A message prompts you:

![Software: refresh packages informations](img/08-admin/17-logiciels-depots-3.jpg)

![Software: cache refreshing](img/08-admin/18-logiciels-depots-4.jpg)

### Automatic updates with Software

To take advantage of your system without worrying about updates, you can 
activate the **automatic updates** mechanism. From the "Software" menu, select 
"Update Preferences". The entries are self-explanatory:

![Software: preferences menu](img/08-admin/19-logiciels-menu-update.jpg)

![Software: automatic updates](img/08-admin/20-logiciels-update-rules.jpg)

## Discover: the KDE package manager

![](img/apps/discover.png#left)  
Gnome uses "Software" to manage 
applications in a simplified way, KDE integrates **Discover**, an intuitive and 
efficient program.

Discover allows you to search, install, remove or update 
your applications from a single interface. You can also modify 
your software sources in order to install - or not - some non-free applications.

**Discover** is launched simply from the KDE main menu > Applications> System > 
Software Center:

![Discover launcher](img/08-admin/21-kde-discover-launcher.jpg)

![Discover: default interface](img/08-admin/22-kde-discover.jpg)

Don't hesitate to browse though the application, you will be asked to confirm 
any modification done to your packages.

### Search and install with Discover

To find an application, type its name in the dedicated search field or visit 
the various categories of Discover. Then a click on the "Install" button is enough:

![Searching an application with Discover](img/08-admin/23-kde-discover-search.jpg)

![Browsing through categories with Discover](img/08-admin/24-kde-discover-categories.jpg)

You will be asked for confirmation for any action on the software together with 
the administrator password. The process will then be launched in the background. 
You can follow the progress of the modifications within the KDE 
notification area.

#### Install Plasma desktop widgets and addons

Discover allows you to add additional components to your Plasma environment. 
To achieve this, visit the "Plasma add-ons" section.

![Discover: Plasma desktop addons](img/08-admin/25-kde-discover-modules-plasma.jpg)

Some additional modules are also available for your applications:

![Discover: applications addons](img/08-admin/26-kde-discover-modules-apps.jpg)

### Uninstalling an application with Discover

With Discover, simply visit the "Installed" 
category then click on "Remove":

![Uninstalling with Discover](img/08-admin/27-kde-discover-installed.jpg)

### Discover: updating your applications

![KDE update notification](img/08-admin/28-kde-update-01-notify.jpg) 
![Discover: updates available](img/08-admin/29-kde-update-02-display.jpg)

When KDE notifies you of one or more updates, it is "Discover" which performs them. 
To check updates "manually", click on the dedicated button:

![Discover: check updates](img/08-admin/30-kde-update-check.jpg)

Simply click on "Update all" and confirm with the administrator password.

![Discover: launching update](img/08-admin/31-kde-update-03-update.jpg)

![Discover: password requested for update](img/08-admin/32-kde-update-04-password.jpg)

![Discover: update progress](img/08-admin/33-kde-update-05-updating.jpg)

Likewise the software management, you can follow the process within the KDE 
notification area. And a message will inform you at the end of the process.

![Discover: system updated](img/08-admin/34-kde-update-06-updated.jpg)

### Discover: managing repositories

The KDE software library allows you to modify the sources of your applications 
without using the terminal. Go to the "Parameters" section of Discover, the entries
display the repositories adresses of your *sources.list*:

![Discover: managing repositories](img/08-admin/35-kde-discover-sources.jpg)

## Synaptic: the comprehensive package manager

![](img/apps/synaptic.png#left)  
**Synaptic** is the comprehensive graphical interface of the Debian package manager. 
It allows a total vision of the proposed packages, whether installed or not. It is 
a lot more detailed than the Software Center, or Discover (see the previous chapters) 
since it displays the **full set**  of available packages (including the libraries).

- It provides the same functionality as apt.
- You need to enter the administrator password to open and use Synaptic.
- An active Internet connection is also needed to install or update your software.

![](img/misc/warning.png#left)  
**Warning** : under Debian 10, Synaptic cannot be used within a "Wayland" session
(Gnome environment), because, for security reasons, graphical applications in root 
mode are forbidden. However, Synaptic remains fully functional within a X session 
(X11, Xorg within Xfce or LXDE environments).

To find out if your environment is running under Wayland, identify your session type,
within a terminal, by executing the command :

    echo $XDG_SESSION_TYPE

which will simply return either "Xorg" or "wayland".

### Synaptic: Main interface

![Synaptic: the default interface of the package manager](img/08-admin/36-synaptic.jpg)

The Synaptic window is divided into 4 areas: the tool bar at the top, the left 
pane allowing different ways of sorting and selecting the packages, the center 
pane displaying the package list itself, and below it, the pane hosting the description 
of the currently selected package (the selection is done by a click).

In front of each package, you notice a little box (white for non-installed 
packages, green when they are installed, red when they are broken).
Next to this status box, a Debian logo indicates that this package is 
"free" (as in freedom).

Don't hesitate to click on all the different menus to explore Synaptic and become more 
familiar with it. It is a good way to discover its numerous functionalities.  
Don't be afraid to break your system since nothing will really happen until 
you click on the "Apply" button. On top of that, a message asking for 
confirmation will always be displayed first.

**The very first thing to do** when you launch Synaptic, is to **click on the 
"Reload" button** in order to update all the information (metadata) concerning 
the repositories, the packages and the available applications.

![Synaptic: repository check](img/08-admin/37-synaptic-recharger.jpg)

### Managing the repositories with Synaptic

The repositories allow to update and install additional packages.  
The repositories have been configured during the installation process but you can 
manage them at any time, if you need to. Open the Synaptic package manager (menu 
System > Synaptic package manager). In the top menu bar, click on "Settings, 
and then "Repositories".

![Synaptic: repositories menu](img/08-admin/38-synaptic-depots-1.jpg)

![Synaptic: updates setting](img/08-admin/39-synaptic-depots-2.jpg)

You'll notice that the list corresponds to the contents of the 
/etc/apt/sources.list file mentioned in [chapter 8.1.1](#the-sources.list-file).  
Now, you can modify your repository sources at your entire convenience. Simply 
click on a source to modify it, or on the "New" button to add another source.  
Once your modifications are validated, the application will invite you to 
reload the repositories list in order to take your changes into account.

Note that if you want to use a "check-box-only" simplified interface on one 
of the Xfce, LXDE or LXQt desktops, you need to install the "software-properties-gtk" package.

![Synaptic: graphical mode sources managment](img/08-admin/40-synaptic-depots-gtk.jpg)

### Updating the system with Synaptic

Before updating the system, it is necessary to "Reload" the package list, 
by clicking on the corresponding button, or by going in the menu "Edit > 
Reload Packages Information" (or even [Ctrl]+r if you want to use a keyboard 
shortcut). This action checks if the version of the packages residing on 
your system is the most recent one or not.

![Synaptic: check repositories informations](img/08-admin/37-synaptic-recharger.jpg)

Then click on "Mark All Upgrades" or goto menu "Edit > Mark All Upgrades...".  
If nothing happens, after you clicked on “Upgrade everything”, this means that 
your system is already up-to-date. You can close Synaptic.

If some packages to install or update are available, they are specified.
You can view them by selecting the "Status" section > "installed (upgradable)":

![Synaptic: upgradable packages list](img/08-admin/42-synaptic-upgrade-1.jpg)

A new window appears with the list of the packages to be upgraded as well 
as the additional dependencies, if some are required:

![Synaptic: change request list](img/08-admin/43-synaptic-upgrade-2.jpg)

You only have to click on the "Add to selection" then "Apply" button, and accept 
the requested confirmation:

![Synaptic: apply update](img/08-admin/44-synaptic-upgrade-3.jpg)

![Synaptic: confirm changes](img/08-admin/45-synaptic-upgrade-confirm.jpg)

The system updating process begins by downloading the packages, and 
continues with their installation.

![Synaptic: downloading packages](img/08-admin/46-synaptic-upgrading.jpg)

A message informs you that all the changes were applied.

![Synaptic: system upgraded](img/08-admin/47-synaptic-upgraded.jpg)

### Searching for a software

**If you know the name of the package** or if you are looking precisely for 
something, click on the search button (in the top bar) and enter the keywords 
of your search in the window which opens.

![Synaptic: search for an application](img/08-admin/48-synaptic-rechercher.jpg)

**If you don't know the name of the package** you need, you can parse the list 
using the filtering by sections, status, origin, etc ...

For example, if you are looking for a game, click on Sections in the bottom part 
of the left pane, scroll down to the "Games and Amusement" section, click on it, 
and all the packages concerning games and amusement are showing up in the center pane. 

### Installing a package with Synaptic

**To install** one or several packages, right-click on the little box in front 
of the package name, and select the "Mark for Installation" option.

![Synaptic: marking a package for installation](img/08-admin/49-synaptic-install-select.jpg)

If, in order to be functional, this package requires the installation of other 
packages (the famous dependencies) they are automatically added to the selection.

![Synaptic: dépendencies added](img/08-admin/50-synaptic-install-changements.jpg)

Then, you simply need to click on the "Apply" button, and confirm the summary 
of the changes to be applied.

![Synaptic: apply changes](img/08-admin/51-synaptic-appliquer.jpg)

![Synaptic: summary of waiting changes](img/08-admin/52-synaptic-install-confirm.jpg)

Packages are downloaded and installed. You can follow the whole process within the
synaptic interface:

![Synaptic: downloading the packages to be installed](img/08-admin/53-synaptic-installing.jpg)

![Synaptic: successful operation](img/08-admin/54-synaptic-success.jpg)

#### Reinstall a package

Sometimes we want to re-install a package which is already installed. In that 
case select the "Mark for Reinstall" option. This allows, for example, 
to restore the default configuration for the application if you modified it.

### Uninstall a package with Synaptic

Like for the installation, right-click on the little box in front of the package 
name, and select the "Mark for Removal" option. Then click on "Apply".

**The simple removal** keeps the package configuration files on your system, 
in case you would like to re-install it, later on.

**To remove also the configuration files** select the "Mark for Complete Removal" 
option (equivalent to the "purge" in a terminal command line)

![Synaptic: selecting a package for removal](img/08-admin/55-synaptic-remove.jpg)

#### Synaptic: cleaning useless packages

Often, when software is uninstalled, some packages (the dependencies) remain 
in the system while no longer useful, since all the packages needing them are 
gone. These useless packages can be easily removed with Synaptic.

When Synaptic is launched, click on the "Status" button at the bottom of the left 
pane. If the "Installed (Auto removable)" category shows up, click on it to 
display the corresponding package(s) (see image below):

![Synaptic: auto removable packages](img/08-admin/56-synaptic-suppress.jpg)

All you have to do next is a right-click on each package in the center pane, and 
select the "Mark for Complete Removal" option. Once all the packages are marked, 
click on the "Apply" button.

#### Removing configuration residues

Although one choose to completely remove a software, some configuration residues 
might still remain in the system, but they can also be easily removed with Synaptic.  
Click on the "Status" button at the bottom of the left pane. If the category 
"Not installed (residual config)" shows up, select it.  
All you have to do next is a right-click on each package in the center pane, and 
select the "Mark for Complete Removal" option. Once all the packages are marked, 
click on the "Apply" button.

![Synaptic: configuration residues](img/08-admin/57-synaptic-residus.jpg)

### Look at detailed information on a package

By clicking on a package, its description is displayed on the bottom center pane 
of Synaptic. To obtain even more information on a package, right-click on it, 
and select Properties, or go to menu "Packages > Properties".

Then you will know everything - positively absolutely everything - on this 
package: dependencies, installed files, size and version.

### Synaptic preferences

"Preferences" is a well-named category, existing in most applications, and 
which is also present here...  
**But keep in mind that Synaptic is a very special case**: it manages the full 
set of software installed on your system. When you remove a program, it does 
not go in the wastebasket (where you could have potentially retrieved it) !

After these scary warnings, let's move to the settings available for Synaptic. 
the Preferences window (launched via menu Settings > Preferences) displays 6 
different tabs:

![Synaptic: Preferences window](img/08-admin/58-synaptic-preferences.jpg)

- **General**: the options in there are rather explicit. Note: it is possible 
to un-check the option "Consider recommended packages as dependencies", if that 
helps you keeping an ultra-light system. But this could induce problems when 
installing future new packages. Thus an option to be handled carefully.
- **Columns and Fonts**: allows you to display/mask some columns in the 
package list, and define the font, if necessary. 
- **Colors**: you can define here the package colors according to their status.
- **Files**: When you install a piece of software, it is first stored in the 
*cache* (which is a specific folder of the file system) before being uncompressed 
and installed. These packages can occupy more and more disk space as you make 
usage of your computer. Here you can delete them immediately or configure an 
automatic action.
- **Network**: This is the way Synaptic connects to Internet. You should know 
if your situation requires a modification of these parameters.
- **Distribution**: Defines the package upgrade behavior and is very explicit. 
**In case of doubts, do not modify it!**

**Remember**: by using a terminal ([chap.8.2](#apt-in-a-terminal)) you can achieve 
the same results more quickly and with less manipulations.

## Cleaning the system

![](img/apps/clean.png#left)  
Even if the capacity of hard disks increased dramatically during the last years, 
you might need some free space. Several scripts automate the disk cleaning process, 
however I must confess that I prefer to check before using the **rm** command 
(standing for **r**e**m**ove. [chap.11.2](#action-on-files-or-directories)).

### Disk space information

The first thing to do, of course, is to find out the used space on your disk. 
Several tools are available to you, starting with your terminal:

**-- Disk space in terminal mode --** A summary of the disk space usage for each system 
mount points (disks and partitions) with th **df** command:

    df -h
    Filesystem     Size    Used Avail Use% MountPoint
    udev           983M       0  983M   0% /dev
    tmpfs          200M    8,1M  192M   5% /run
    /dev/sda1       48G     16G   30G  35% /
    tmpfs          998M       0  998M   0% /dev/shm
    tmpfs          5,0M    4,0K  5,0M   1% /run/lock

**-- List your repertories sorted by decreasing size --** View your directories
bulky thanks to **du** and **sort** (the unit is the megabytes):

    user@debian-pc:~$ du -ms * | sort -nr
    585  Music
    281  Videos
    232  Documents
    42   Pictures
    26   Dowloads
    1    Desktop

**-- Ncdu --** A disk space analyzer in console mode. To launch it, simply type 
"ncdu" in your terminal. To install this software (in administrator mode):

    apt update && apt install ncdu

![Ncdu launched in the user personal folder](img/08-admin/59-ncdu.jpg)

**-- Baobab --** A disk space analyzer in graphic mode, integrated in Gnome but 
available in other environments with:

    apt update && apt install baobab

![Baobab: disk space analyzer on Gnome](img/08-admin/60-baobab.jpg)

**-- Fslint --** utility to find and clean various forms of unwanted extraneous files 
in your file system, like duplicates, broken links, empty folders, wrong encoding, 
etc ... **To be manipulated with extreme caution**: double check carefully the pending 
changes before validating the whole process.

![FSlint: system cleaner...](img/08-admin/61-fslint.jpg)

### Cleaning the packages

**Apt**/aptitude/dpkg are the usual Debian package managers. When you install a 
package its archive-source/deb file is stored in your system 
(in the /var/cache/apt/archives/ folder) to enable a potential re-installation 
without Internet connection. To clean the "apt cache" use a simple command in 
administrator mode ([chap.3.8.3](#administrator-mode-example)):

    apt clean

Once the cache of the installed packages is cleaned, you can also remove the 
useless packages from your system, as well as the configuration files. **Warning!** 
Remember to check carefully the list of the packages planed for removal, before 
accepting the operation:

    apt autoremove --purge

### Emptying the trash bins

Three different trash-bins (or wastebaskets) must be taken into account:

**The user wastebasket** : ~/.local/share/Trash/ . You can empty it with the 
system file manager ([chap.3.6.2.5](#data-removal)), or with a terminal:

    rm -Rf ~/.local/share/Trash/*

**The administrator wastebasket** : /root/.local/share/Trash/ . To empty it 
with the proper manner, use a terminal in administrator mode:

    rm -Rf /root/.local/share/Trash/*

**The external wastebaskets** : locates on your external disks, they are 
usually named '/media/your_id/your_disk/.Trash_1000', where your_id 
corresponds to your login name.

### Purging application caches

Some applications use a "cache" folder, where they store images, videos, and 
miscellaneous information in order to run faster. Usually these data do not 
occupy too much disk space, however if (using the tools described above) you 
detect that a folder becomes too fat, don't hesitate to remove it.

Each application has its own way to manage its own cache: some purge it 
systematically when they close, others store their data in the /tmp folder, 
which will be cleared during the session logout, others keep all their 
information in a specific folder.

For Firefox, as an example, you can purge the cache from the preferences menu, 
and even automate this action every time the application is closed.

### Purging the thumbnails

Every time you open a folder containing pictures or videos, thumbnails are 
created to represent these graphic files. These thumbnails are stored in a 
specific folder to reuse them, rather than being forced to recompute them 
every time you access this kind of files.  
The problem raises when you delete a graphic file, because its thumbnail is 
kept in the system, and this leads to a certain amount of disk space wasted 
to store obsolete thumbnails.  
To purge them, it is enough to remove their corresponding folder:

    rm -Rf ~/.thumbnails

This folder will be created again, the next time the system needs to store a 
newly generated thumbnail.

## Installing external ".deb" packages

Debian GNU/Linux uses the package repository system to better manage the software 
and increase the security of your system. But it may happen that you need an 
external package of the ".deb" format.

![](img/misc/noob-info.png#left) 
**... but who is this "deb" ??**  
**deb** is the short for "debian", the mother company. To distribute its software, 
Debian uses a specific archive file format: ".deb". It is a compressed format, 
like the ".zip" that you use to save your data. These ".deb" archives are recognized 
by the different Debian package managers (APT and its graphical interface Synaptic) 
and thus can be handled more easily.

### Installation in graphic mode with GDebi

GDebi is a graphical utility with allows the installation of external packages 
of the ".deb" format, while managing the dependencies.

To install it, look for "gdebi" in your favorite package manager (Synaptic, 
Discover, Software) or more simply from a terminal in administrator mode using 
"**su**" ([chap.3.8.3](#administrator-mode-example)):

    apt update && apt install gdebi

When you download a Debian external package, right-click on it and select 
"Open with gdebi".

![GDebi: the default interface](img/08-admin/62-gdebi-1.jpg)

Within the menu, click on File > Open and enter the path of the “.deb” file:

![GDebi: opening a .deb file](img/08-admin/63-gdebi-2.jpg)

Then click on “Install Package”. Your password is requested to validate the 
install.

![GDebi: installing a .deb file](img/08-admin/64-gdebi-3.jpg)

![GDebi: installing a .deb file](img/08-admin/65-gdebi-4.jpg)

To uninstall it, very easy : enough to click on “Remove Package”.

![GDebi: remove a .deb file](img/08-admin/66-gdebi-5.jpg)

### Installation in terminal mode with Dpkg

Dpkg is a software utility handling the packages, like does apt, but without managing 
the dependencies. This means that if you use dpkg to install external packages, 
you need to install the "dependent" packages one by one from your terminal. Dpkg 
is integrated in Debian by default, and must be used in administrative mode.

**To install an external package:**

    dpkg -i package_name.deb

An error message will let you know if some dependencies are missing. 
Then simply install them the classic way with apt:

    apt install dependency_1 dependency_2 ...

Then relaunch the installation of your external package.

    dpkg -i package_name.deb

**To remove an external package:**

    dpkg --purge package_name

## Installing Flatpak applications

![](img/apps/flatpak.png#left)  
**Flatpak** ([https://docs.flatpak.org/en/latest/getting-started.html](https://docs.flatpak.org/en/latest/getting-started.html)) 
is a virtualization application system for GNU/Linux distributions. 
The objective is to provide a safe "sandbox" environment, isolated from 
the rest of the system, where users can run applications not validated 
by the distribution repositories (test versions, for example). 
*dixit Wikipedia*

![](img/misc/noob-info.png#left)  
**... I virtualize in the sandbox ...?**  
The applications that you download from the Debian repositories are 
 ".deb" formated archives containing the application itself. These applications 
use common dependencies, are linked to each other, and have access to your entire 
system. Debian repositories are secure, so no worries about this issue. 
But then why should we use Flatpak?  
The Flatpak format works differently: the application is compressed with all its 
dependencies, making it completely independent of the system on which it is 
installed. So, here you can install and use a freshly updated application or even 
a brand new one, compared to the Debian repositories.  
The second advantage of this format is the famous "sandbox". The *sandbox* is a 
kind of secure box in which the application runs, without having access to the 
rest of the system (with exceptions, when the user gives its authorization), thereby 
preventing malicious software from going through your application to contaminate 
your system.  
The last advantage is that it enables you to run multiple versions of the same 
application (very practical for Minetest and servers in different versions).  
The downside of this format is that it is not verified by the Debian security: 
when installing *flatpaks*, you should prefer trusted referenced applications 
(Gimp, VLC, Blender ...).

### Installing Flatpak

To take advantage of applications in Flatpak format, you must first 
install the corresponding package. From your terminal in administrator mode 
([chap.3.8.3](#administrator-mode-example)) :

    apt install flatpak

You can now download and install *flatpak* packages by visiting one of the 
websites grouping these applications like Flathub 
([https://flathub.org/home](https://flathub.org/home)). But the simplest way 
consists to add a repository to your sources in order to take advantage of the 
full applications lists without having to search through the site.

### Add a Flatpak repository

To add a repository like Flathub for example, and benefit from an easy search 
and a simplified installation, type in your terminal:

    flatpak remote-add flathub https://flathub.org/repo/flathub.flatpakrepo

You will be asked for the administrator password. And you will have to restart 
your system to take the changes into account.

### Manage Flatpak applications under Gnome with [Software](#software-the-simplified-package-manager) ![](img/apps/logiciels-mini.png)

To take advantage of managing *flatpaks* within your software manager, 
you must add the plugin corresponding to your environment. For Gnome and 
its simplified software manager, in a terminal and in administrator mode 
([chap.3.8.3](#administrator-mode-example)) :

    apt install gnome-software-plugin-flatpak

You can now manage your *flatpaks* like any other applications 
(*see* [chap.8.3](#software-the-simplified-package-manager))

![Looking at Flatpak application](img/08-admin/67-flatpak-gnome-1.jpg)

Note the software source indicator at the bottom of the description.

![Installing a Flatpak application](img/08-admin/68-flatpak-gnome-2.jpg)

As with other applications, the administrator password will be 
requested for any installation. Your software will then be directly 
available in your applications menu.

### Manage Flatpak applications under KDE with [Discover](#discover-the-kde-package-manager) ![](img/apps/discover-mini.png)

To benefit from the management of *flatpaks* within Discover, under Kde, you 
must install the appropriate plugin. In a terminal and in administrator mode 
([chap.3.8.3](#administrator-mode-example)):

    apt install plasma-discover-backend-flatpak

You can now manage your *flatpaks* like any other applications 
(*see* [chap.8.4](#discover-the-kde-package-manager)).

During your search, you must click on the software file. Don't click immediately 
on "Install" because Debian repositories have priority.

![Looking for an application with Discover](img/08-admin/69-flatpak-kde-1.jpg)

Select the *flathub* repository from the Discover "Sources" menu. 
Then launch the installation by clicking on "Install":

![Selecting the Flathub repository](img/08-admin/70-flatpak-kde-2.jpg)

As with other applications, the administrator password will be 
requested for any installation. Your software will then be directly 
available in your applications menu.

### Manage Flatpak applications from your terminal

Here after, the basic commands to manage your *flatpaks* from your terminal:

Command                                     Action
------------------------------------------- -----------------------------------
flatpak search flatpak_name                 Search for a flatpak in all repositories
flatpak install *repository* flatpak_name   Installing a flatpak from *repository*
flatpak uninstall flatpak_name              Remove a flatpak
flatpak uninstall \-\-unused                Remove unused dependencies
flatpak update                              Update all installed *flatpaks*
flatpak run flatpak_name                    Launch a *flatpak*

Special case: install a flatpak **for the current user only** with the 
"\-\-user" option. The files will be placed in the user directory 
($HOME/.local/share/flatpak/).

    flatpak --user install *repository* flatpak_name

**Example with LibreOffice:**

Installing LibreOffice from Flathub:

    flatpak install flathub org.libreoffice.LibreOffice
    
To launch the flatpak version of LibreOffice:

    flatpak run org.libreoffice.LibreOffice

### Remove a Flatpak application

If you have installed your flatpak graphically from **Software** or **Discover**, 
just delete it from the installed applications menu from your software manager: 
look for the flatpak to uninstall then start the removal from the dedicated button.  
Note that if you want to uninstall all dependencies (software installed in addition 
to the flatpak for its operation), you will have to launch this command in your terminal:

    flatpak uninstall --unused

### Some Flatpak repositories

To help you in your research, find hereafter some repositories using the Flatpak 
format and the commands to execute in order to add their repositories. You can use 
the "\-\-if-no-exists" option to avoid errors generated by duplicates:

Flathub repository [https://flathub.org/](https://flathub.org/) gathering 
a large number of applications:

    flatpak remote-add flathub https://flathub.org/repo/flathub.flatpakrepo

KDE Flatpak repository:

    flatpak remote-add kdeapps https://distribute.kde.org/kdeapps.flatpakrepo

Gnome-nightly Flatpak repository:

    flatpak remote-add gnome-nightly https://nightly.gnome.org/gnome-nightly.flatpakrepo

## Who is this Sid guy?

First of all, one must know that **several Debian distribution branches** exist 
in parallel.

Namely the **oldstable**, **stable**, **testing** and **unstable** distributions, 
as well as an **experimental** branch.

The **Stable distribution** is the Debian official distribution, the one released 
at this moment, which is maintained and updated by the Debian teams. The only 
changes made to it concern the security updates and the bug fixes. It is recommended 
to favor this version.

The **Oldstable distribution** is the previous stable version. It is usually 
supported by the Debian teams during one year after the release of the new stable 
version. However it might live longer if enough individuals or companies continue to 
assure its maintenance. Then it is called a LTS (standing for Long Term Support) 
distribution: we extend its life span.

The **Testing distribution** is the future Stable version. It is used to prepared 
the next stable version. When everything is OK, when all the bit and pieces are 
functioning well together, when all the features targeted by the Debian teams are 
included, and after a period of software freeze and bug hunting, then the Testing 
version becomes the official new Stable distribution.

The **Unstable distribution**, *nicknamed Sid*, is the version which receives all 
the new packages versions, and sits at the cutting edge of innovation, but is not 
very stable: it's a research lab. Nevertheless some brave adventurers use it on 
a daily basis.

The **Experimental distribution** is not a Debian distribution *per se*, but 
rather a repository where alpha or beta software versions are tested.

![Debian grolsch vector by Paul Sladen](img/logo/debian-grolsch-vector.png){.logo}

All these distributions are given a nickname picked among the characters of the 
Toy Story® cartoon. Currently, the name of the **stable version is Buster**, the 
name of the **testing version is Bullseye**, the name of the **oldstable version 
is Stretch**, the Experimental as no nickname. 

![Toy Story © Disney & Pixar](img/08-admin/71-toystory.jpg)

The first version of Debian with a nickname was the Debian-1.1 "Buzz", 
released as of June 17th, 1996.
(*see* [https://en.wikipedia.org/wiki/Debian_version_history](https://en.wikipedia.org/wiki/Debian_version_history))

The name of **unstable is Sid**, but who is this Sid guy?  
Sid is the little boy, in the Toy story® cartoon, who keeps breaking all his toys 
([http://pixar.wikia.com/wiki/Sid_Phillips](http://pixar.wikia.com/wiki/Sid_Phillips)).

More detailed information on the dedicated Debian Wiki 
[https://wiki.debian.org/DebianUnstable](https://wiki.debian.org/DebianUnstable).

![sid](img/misc/sid.jpg){.logo}

