# ![](img/nav42/term.png) Basic Command Memo

![A shell to rule them all](img/misc/lotr.png){.logo}

Debian GNU/Linux systems have all the graphical applications needed to perform 
your daily tasks, so why to use the command line?

- it's faster,
- not all options are present in the graphical interfaces,
- using the command line without GUI saves resources,
- it makes learning the Debian GNU/Linux system easier.

This section gathers some basic commands. For a more complete list, visit 
the Debian documentation: 
[https://wiki.debian.org/ShellCommands](https://wiki.debian.org/ShellCommands).

## Browse directories

    #Command   #Action
    #----------------------------------------------------------------------
    pwd        Print Working Directory
    cd foo     Change Directory to foo
    cd         Change Directory to /home/$USER or ~/
    cd ..      move up to the parent directory
    ls foo     List information about file(s) in foo
    ls -a      ls with hidden files displayed
    ls -l      ls with size and rights

## Action on files or directories

    #Command               #Action
    #----------------------------------------------------------------------
    mv source target       move the file from source to target
    cp source target       copy the file from source to target
    cp -R source target    copy the directory source to target (recursively)
    ln source link         create a hard link from source to link
    ln -s source link      create a symbolic link from source to link
    touch foo              create the file foo or update its 
                           modification date
    mkdir dirA             create the directory dirA
    mkdir -p dirA/dirB     mkdir with creation of parent directory if needed
    rm foo                 remove file foo
    rm -f file             remove the write-protected file
    rmdir dirA             remove the empty directory dirA
    rm -R dirB             remove the directory dirB (recursively)
    du -h file or dir      display size of the file or the dir

## View/Compare files

    #Command              #Action
    #----------------------------------------------------------------------
    wc file               Prints byte, word and line counts of file
    cat file              displays the contents of a file
    more file             displays file page by page. 'Space'=next page, 
                          'Enter'=next line, 'u'=up
    less file             displays file with fine navigation 
                          Left/Right/Up/Down/PageUp/PageDown
    head -n x file        displays 'x' first lines of file
    tail -n x file        displays 'x' last lines of file
    tail -f file          dynamicaly displays last line of file
    diff file1 file2      Displays differences between two text files
    diff -u file1 file2   Displays differences between file1 and file2 
                          with patch syntax
    comp file1 file2      compares two binary files
    comp file1 file2 n N  compares two files, file1 from the octet n and 
                          file2 from octet N

## Users and goups

    #Command        #Action
    #----------------------------------------------------------------------
    whoami          Print the current user id and name
    who             Print all usernames currently logged in
    id              Print user and group id's (uid & gid)
    id user         Print user and group id's (root only)
    finger user     Print informations about user
    write user      Print a message on user's terminal
    tty             Print the current terminal's name
    su - sudo       Switch to administrator mode, superuser
    passwd          Change the password of the current user
    adduser         add a user
    deluser         delete a user
    addgroup        add a group
    delgroup        delete a group

## Process

    #Command            #Action
    #----------------------------------------------------------------------
    ps                  Process Status. Lists running process
    ps ax               Print all running processes
    ps aux              Print all process identified by users
    pstree              Print all process in a tree
    top                 List processes running on the system in a 
                        semi-graphical table
    kill signal pid     kill a process using its pid
    pkill signal name   kill a process using its name

**Signals** used by *kill/pkill*

    #Signal  #Mode    #Action
    #----------------------------------------------------------------------
    -1       HUP      Reload the process configuration file
    -2       INT      Interrupt the process
    -3       QUIT     Quit the process
    -9       KILL     Kill the process (to avoid, try '-15' first)
    -15      TERM     Complete the process properly
    -18      STOP     Freeze the process
    -20      CONT     Resume execution of a frozen process

## Hardware

    #Command                             #Action
    #----------------------------------------------------------------------
    lsusb                                Lists connected USB devices
    lspci                                Lists connected PCI devices
    cat /proc/cpuinfo                    Displays processor information
    cat /proc/partitions                 Displays mounted partitions
    lspci | egrep "3D|Display|VGA"       Display the graphics card model
    lspci | grep -i "net" | cut -d: -f3  Show the Wifi card model
    lspci | grep -i audio | cut -d: -f3  Show the soundcard model

## Network

    #Command              #Action
    #----------------------------------------------------------------------
    hostname              Print or set system name
    ping machine          Send a ping to a machine on the network
    traceroute machine    Displays a traceroute through machine
    netstat               Displays the use of the network by the processes
    netstat -a            Netstat with the display of the server processes
    lsof                  Detailed list of file and network usage
    ip address            Displays the config of the interfaces
    route                 Displays the routing table
    curl ifconfig.me      Displays public IP

**Example:** displays its locap IP on enp0s3

    ip address show enp0s3 | grep "inet " | tr -s " " ":" | cut -d: -f3

## Search

    #Command/Option      #Action
    #----------------------------------------------------------------------
    locate pattern       Search for file with a pattern name
    updatedb             Update locate database
    find path options    Search for file corresponding to options in path
    find -name pattern   Search for file with a pattern
    find -type f/d/l     Search by filetype: f=file, d=directory, l=link
    find -exec cmd       Execute *cmd* on the found files

**Example**: search for all *png* files in the 'Images' directory, then copy 
all files to *tmp* directory ('**{}**' stands for found files).

    find $HOME/Images -name "*.png" -exec cp {} $HOME/tmp/ \;

## Archives

    #Format          #Compress                             #Extract
    #----------------------------------------------------------------------
    .tar.bz2, .tbz2  tar -cvjf archive.tar.bz2 directory   tar xvjf
    .tar.gz, .tgz    tar -cvzf archive.tar.gz directory    tar xvzf
    .bz2             bzip2 file                            bunzip2
    .rar             -                                     unrar x
    .gz              gzip file                             gunzip
    .tar             tar -cvf archive.tar files            tar xvf
    .zip             zip -r archive.zip files              unzip
    .Z               compress files                        uncompress
    .7z              7z a files                            7z x
    .xz              xz -z directory                       unxz

## Kernel

Version of the Linux kernel used, its name, the version of the compiler used:

    cat /proc/version

Version of the Linux kernel used:

    uname -r

List all kernels installed on your machine:

    dpkg -l | egrep "linux-(header|image)"

## Links and references

- Dedicated page on Debian-Facile (fr): 
[https://debian-facile.org/doc:systeme:commandes:gnu_linux](https://debian-facile.org/doc:systeme:commandes:gnu_linux)
- Dedicated Debian documentation: 
[https://www.debian.org/doc/manuals/debian-reference/ch01.html](https://www.debian.org/doc/manuals/debian-reference/ch01.html)
- Commands list: 
[http://www.epons.org/commandes-base-linux.php](http://www.epons.org/commandes-base-linux.php)
- Commands list on Debian wiki: 
[https://wiki.debian.org/ShellCommands](https://wiki.debian.org/ShellCommands)

![Zen garden by Péhä cc-by-sa](img/peha/zen-garden-peha-cc-by-sa.jpg)

